{% load aa_discord_announcements_versioned_static %}

<link rel="stylesheet" href="{% aa_discord_announcements_static 'aa_discord_announcements/css/aa-bootstrap-fix.min.css' %}">
<link rel="stylesheet" href="{% aa_discord_announcements_static 'aa_discord_announcements/css/aa-discord-announcements.min.css' %}">
